| Title: | Easily Install and Load `SticsRPacks` Packages |
|---|---|
| Description: | A set of packages that work in harmony because they share common data representations and "API" design. This package is designed to make it easy to install and load multiple `SticsRPacks` packages in a single step. Learn more about `SticsRPacks` at <https://sticsrpacks.github.io/SticsRPacks/>. |
| Authors: | Remi Vezy [aut, cre] (ORCID: <https://orcid.org/0000-0002-0808-1461>), Samuel Buis [aut] (ORCID: <https://orcid.org/0000-0002-8676-5447>), Patrice Lecharpentier [aut] (ORCID: <https://orcid.org/0000-0002-4044-4322>), Michel Giner [aut] (ORCID: <https://orcid.org/0000-0002-9310-2377>) |
| Maintainer: | Remi Vezy <[email protected]> |
| License: | LGPL (>= 3) |
| Version: | 0.10.0 |
| Built: | 2026-06-01 07:43:15 UTC |
| Source: | https://github.com/SticsRPacks/SticsRPacks |
This function lists all the conflicts between packages in SticsRPacks and other packages that you have loaded.
SticsRPacks_conflicts()SticsRPacks_conflicts()
SticsRPacks_conflicts()SticsRPacks_conflicts()
List all SticsRPacks dependencies
SticsRPacks_deps()SticsRPacks_deps()
Use crayon::strip_style() to get rid of the colors.
SticsRPacks_logo(unicode = l10n_info()$`UTF-8`)SticsRPacks_logo(unicode = l10n_info()$`UTF-8`)
unicode |
Whether to use Unicode symbols. Default is |
SticsRPacks_logo()SticsRPacks_logo()
List all packages in SticsRPacks
SticsRPacks_packages(include_self = TRUE)SticsRPacks_packages(include_self = TRUE)
include_self |
Include SticsRPacks in the list? |
SticsRPacks_packages()SticsRPacks_packages()
This function gives a quick overview of the versions of R and RStudio as well as all SticsRPacks packages. It's primarily designed to help you get a quick idea of what's going on when you're helping someone else debug a problem.
SticsRPacks_sitrep()SticsRPacks_sitrep()
This will check to see if all SticsRPacks packages are up-to-date, and install the desired version if not.
SticsRPacks_update( ref = list(SticsRFiles = NULL, CroptimizR = NULL, SticsOnR = NULL, CroPlotR = NULL) )SticsRPacks_update( ref = list(SticsRFiles = NULL, CroptimizR = NULL, SticsOnR = NULL, CroPlotR = NULL) )
ref |
The desired git reference. Could be a commit, tag, or branch name. Defaults to NULL for the latest release of the package. |
## Not run: # Use the latest release: SticsRPacks_update() # Using a particular commit for one: SticsRPacks_update(ref = list(SticsRFiles = "42f9333e1b1c336cf431e2e33dc13caa994a3ae9")) # Or a version: SticsRPacks_update(ref = list(SticsRFiles = "v0.1.0.9003")) ## End(Not run)## Not run: # Use the latest release: SticsRPacks_update() # Using a particular commit for one: SticsRPacks_update(ref = list(SticsRFiles = "42f9333e1b1c336cf431e2e33dc13caa994a3ae9")) # Or a version: SticsRPacks_update(ref = list(SticsRFiles = "v0.1.0.9003")) ## End(Not run)
Update all SticsRPacks dependencies
SticsRPacks_update_deps()SticsRPacks_update_deps()